We get quite a number of people who have never done user-interface programming before in their lives on the pyjamas-dev mailing lists, let alone having done any web programming: you're in good company.

Start with the "getting started" tutorial, ignoring the first paragraphs because they don't apply to you! Many web designers actually have to "unlearn" their expectations that this is going to be horrendously painful, and you are at a distinct advantage because you've not experienced their disillusionment and frustration of the past decade, over CSS, browser and AJAX incompatibilities.